@@ -1,9 +1,8 @@
 /*
-* Copyright (c) 2021-2023 Golubchikov Mihail <https://github.com/rue-ryuzaki>
-*/
+ * Copyright (c) 2021-2024 Golubchikov Mihail <https://github.com/rue-ryuzaki>
+ */
 
-#include <argparse/argparse.hpp>
-#include "./catch-define.h"
+#include "./argparse_test.hpp"
 
 #include <map>
 
